# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.paginated_ldap_source_list import PaginatedLDAPSourceList

class TestPaginatedLDAPSourceList(unittest.TestCase):
    """PaginatedLDAPSourceList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PaginatedLDAPSourceList:
        """Test PaginatedLDAPSourceList
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PaginatedLDAPSourceList`
        """
        model = PaginatedLDAPSourceList()
        if include_optional:
            return PaginatedLDAPSourceList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.ldap_source.LDAPSource(
                        pk = '', 
                        name = '', 
                        slug = 'z', 
                        enabled = True, 
                        authentication_flow = '', 
                        enrollment_flow = '', 
                        user_property_mappings = [
                            ''
                            ], 
                        group_property_mappings = [
                            ''
                            ], 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        policy_engine_mode = 'all', 
                        user_matching_mode = null, 
                        managed = '', 
                        user_path_template = '', 
                        icon = '', 
                        server_uri = '', 
                        peer_certificate = '', 
                        client_certificate = '', 
                        bind_cn = '', 
                        start_tls = True, 
                        sni = True, 
                        base_dn = '', 
                        additional_user_dn = '', 
                        additional_group_dn = '', 
                        user_object_filter = '', 
                        group_object_filter = '', 
                        group_membership_field = '', 
                        user_membership_attribute = '', 
                        object_uniqueness_field = '', 
                        password_login_update_internal_password = True, 
                        sync_users = True, 
                        sync_users_password = True, 
                        sync_groups = True, 
                        sync_parent_group = '', 
                        connectivity = {
                            'key' : {
                                'key' : ''
                                }
                            }, 
                        lookup_groups_from_user = True, 
                        delete_not_found_objects = True, )
                    ],
                autocomplete = {
                    'key' : null
                    }
            )
        else:
            return PaginatedLDAPSourceList(
                pagination = authentik_client.models.pagination.Pagination(
                    next = 1.337, 
                    previous = 1.337, 
                    count = 1.337, 
                    current = 1.337, 
                    total_pages = 1.337, 
                    start_index = 1.337, 
                    end_index = 1.337, ),
                results = [
                    authentik_client.models.ldap_source.LDAPSource(
                        pk = '', 
                        name = '', 
                        slug = 'z', 
                        enabled = True, 
                        authentication_flow = '', 
                        enrollment_flow = '', 
                        user_property_mappings = [
                            ''
                            ], 
                        group_property_mappings = [
                            ''
                            ], 
                        component = '', 
                        verbose_name = '', 
                        verbose_name_plural = '', 
                        meta_model_name = '', 
                        policy_engine_mode = 'all', 
                        user_matching_mode = null, 
                        managed = '', 
                        user_path_template = '', 
                        icon = '', 
                        server_uri = '', 
                        peer_certificate = '', 
                        client_certificate = '', 
                        bind_cn = '', 
                        start_tls = True, 
                        sni = True, 
                        base_dn = '', 
                        additional_user_dn = '', 
                        additional_group_dn = '', 
                        user_object_filter = '', 
                        group_object_filter = '', 
                        group_membership_field = '', 
                        user_membership_attribute = '', 
                        object_uniqueness_field = '', 
                        password_login_update_internal_password = True, 
                        sync_users = True, 
                        sync_users_password = True, 
                        sync_groups = True, 
                        sync_parent_group = '', 
                        connectivity = {
                            'key' : {
                                'key' : ''
                                }
                            }, 
                        lookup_groups_from_user = True, 
                        delete_not_found_objects = True, )
                    ],
                autocomplete = {
                    'key' : null
                    },
        )
        """

    def testPaginatedLDAPSourceList(self):
        """Test PaginatedLDAPSourceList"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
